rnalysis.general
================

.. automodule:: rnalysis.general

   
   
   .. rubric:: Functions

   .. autosummary::
   
      check_is_df
      filter_low_rpm
      is_reference_table_defined
      load_csv
      norm_reads_to_rpm
      normalize_file
      parse_gene_name_string
      parse_sequence_name_string
      parse_wbgene_string
      read_reference_table_path
      remove_unindexed_rows
      save_to_csv
      set_reference_table_path
      start_ipcluster
      start_parallel_session
      stop_ipcluster
   
   

   
   
   

   
   
   